# Explanation

<!-- diataxis: explanation -->

Concepts, architecture, and design decisions behind plone.pgthumbor and
zodb-pgjsonb-thumborblobloader.
Read these to deepen your understanding of
how and why the system works the way it does.

```{toctree}
---
maxdepth: 2
titlesonly: true
---
architecture
security
why-thumbor
cloud-native
```
